<?php

$strings = array(
		'Cache Legends'
		=> 'Cache 說明',
		'List Legends'
		=> 'List 說明',
		'XCache Administration Help'
		=> 'XCache 管理頁面說明訊息',
		'Help'
		=> '說明',
		'Slots'
		=> '槽',
		'Size'
		=> '大小',
		'Avail'
		=> '剩餘',
		'Used'
		=> '已用',
		'Clear'
		=> '清除',
		'Sure to clear?'
		=> '確認要清除嗎?',
		'Compiling'
		=> '編譯中',
		'% Free'
		=> '% 剩余',
		'% Used'
		=> '% 已用',
		'Hits'
		=> '命中',
		'Hits 24H'
		=> '24H 分布',
		'Hits/H'
		=> '命中/H',
		'Hits/S'
		=> '命中/S',
		'Misses'
		=> '錯過',
		'Clogs'
		=> '阻塞',
		'OOMs'
		=> '記憶體不足',
		'Errors'
		=> '错误',
		'Protected'
		=> '保護',
		'Cached'
		=> '快取',
		'Deleted'
		=> '待刪',
		'Delete'
		=> '刪除',
		'Free Blocks'
		=> '空閒塊',

		'entry'
		=> '項目',
		'Refcount'
		=> '引用數',
		'SrcSize'
		=> '原始檔案大小',
		'Modify'
		=> '修改',
		'device'
		=> '設備',
		'inode'
		=> 'Inode',
		'hash'
		=> 'Hash',
		'Access'
		=> '存取',
		'Create'
		=> '建立',
		'See also'
		=> '建議參考',
		'GC'
		=> 'GC',
		'Legends:'
		=> '图例:',
		'Used Blocks'
		=> '已用块',
		'Free Blocks'
		=> '未用块',
		'Total'
		=> '总共',
		'Cache'
		=> '快取',
		'Caches'
		=> '快取',
		'Cached'
		=> '快取',
		'php Cached'
		=> '快取的 php 指令',
		'php Deleted'
		=> '待刪 php 指令',
		'var Cached'
		=> '快取的變數',
		'var Deleted'
		=> '待刪變數',
		'Statistics'
		=> '摘要統計',
		'List PHP'
		=> '列出PHP',
		'List Var Data'
		=> '列變數資料',
		'XCache %s Administration'
		=> 'XCache %s 管理頁面',
		'size'
		=> '大小',
		'offset'
		=> '位置',
		'Module Info'
		=> '組元訊息',
		'Remove Selected'
		=> '移除所选',
		'Editing Variable %s'
		=> '正在编辑变量 %s',
		''
		=> '',
		);

